------------------------------
--      Targeting           --
------------------------------

BigWigsKLHTMTarget.unitIds = {
	"target";
};

-- helper function
function BigWigsKLHTMTarget:InsertIds(t, number, formatStr)
	for i=1,number do
		tinsert(t, format(formatStr, i));
	end
end

local unitPrefixes = {
	{ 
		formatStr = "party%dtarget";
		number = 5;
	};
	{
		formatStr = "raid%dtarget";
		number = 40;
	};
};
for k, v in pairs(unitPrefixes) do
	BigWigsKLHTMTarget:InsertIds(BigWigsKLHTMTarget.unitIds, v.number, v.formatStr);
end

-- name => name of entity to target
-- @return => the unitId of the entity or nil if no unitId can be found
function BigWigsKLHTMTarget:GetNameAsUnit(name)
	for k, v in self.unitIds do
		if ( UnitExists(v) ) and ( UnitName(v) == name ) then
			return v;
		end
	end
	return nil;
end

-- name => name of boss
-- strict => whether to check that the boss is engaged 
--           with one of your party/raid members.
-- @return => true if you are engaged with the boss, otherwise false
function BigWigsKLHTMTarget:IsEngagedWithName(name, strict)
	if ( not UnitAffectingCombat("player") ) then
		return false;
	end
	local unit = self:GetNameAsUnit(name);
	if ( unit ) and ( UnitAffectingCombat(unit) ) then
		-- TODO: optional check for enemy targeting a partied unit
		if ( strict ) then
			local unitTarget = unit.."target";
			if ( not UnitPlayerOrPetInParty(unitTarget) ) and ( not UnitPlayerOrPetInRaid(unitTarget) ) then
				return false;
			end
		end
		return true;
	else
		return false;
	end
end

-- name => name of entity to target
-- @return => true if entity is targeted, otherwise false
function BigWigsKLHTMTarget:DoTarget(name)
	--TargetByName(unit, true)
	local unit = self:GetNameAsUnit(name);
	if ( unit ) then 
		if ( unit ~= "target" ) then
			TargetUnit(unit);
		end
		return true;
	else
		return false;
	end
end

